# ==================================================  ===========================
# >> Imports
# ==================================================  ===========================

from events import Event
from players.helpers import index_from_userid
from players.helpers import playerinfo_from_userid
from players.entity import PlayerEntity
from entities.constants import DamageTypes
from messages import HintText
from cvars import cvar
from cvars.public import PublicConVar
from plugins.info import PluginInfo

# =============================================================================
# >> ADDON INFO
# =============================================================================

info = PluginInfo()
info.name = 'One Shot One Kill'
info.author = 'UltiNaruto'
info.version = '3.4'
info.basename = 'oneshotonekill'
info.variable = "{0}_version".format(info.basename)
info.url = 'http://forums.sourcepython.com/showthread.php?682-One-Shot-One-Kill-v3-4'

# =============================================================================
# >> PUBLIC VARIABLE
# =============================================================================

info.convar = PublicConVar(info.variable, info.version, 0, "{0} Version".format(info.name))

# ==================================================  ===========================
# >> Functions
# ==================================================  ===========================

def load():
    HintText(message='[ONE SHOT ONE KILL %s] Loaded' % info.version).send()

def unload():
    HintText(message='[ONE SHOT ONE KILL %s] Unloaded' % info.version).send()

@Event
def player_spawn(GameEvent):
    userid = GameEvent.get_int('userid')
    myPlayer = PlayerEntity(index_from_userid(userid))
    myPlayer.set_prop_int("m_bHasHelmet", 0)
    myPlayer.set_prop_int("m_ArmorValue", 0)
    myPlayer.health = 5000

@Event
def player_hurt(GameEvent):
    victim = GameEvent.get_int('userid')
    victimPlayer = PlayerEntity(index_from_userid(victim))
    damage = GameEvent.get_int('dmg_health')
    weapon = GameEvent.get_string('weapon')
    if victimPlayer.health - damage - 1 <= 0:
        return
    attacker = GameEvent.get_int('attacker')
    if not is_valid_attack(attacker, victim):
        victimPlayer.health = 5000
        return
    myPlayer = PlayerEntity(index_from_userid(attacker))
    victimPlayer.health = 0
    myPlayer.damage(index_from_userid(victim), 1, DamageTypes.BULLET, hitgroup=2, iObjectsPenetrated=0, weapon_index=weapon)

def is_valid_attack(attacker, victim):
    if attacker == victim:
        return False
    mp_teammates_are_enemies = cvar.find_var('mp_teammates_are_enemies')
    vplayer = PlayerEntity(index_from_userid(victim))
    aplayer = PlayerEntity(index_from_userid(attacker))    
    if vplayer.team == aplayer.team and mp_teammates_are_enemies.get_int() == 0:
        return False
    return True